#include "include/sql.h"


const char *klist_sql_get(const enum KLIST_SQL sql) {
    switch (sql) {
        case INIT: return
            "create table if not exists users (\n"
            "    id integer primary key,\n"
            "    name text not null,\n"
            "    local_id integer,   -- if the thing is running locally\n"
            "    discord_id integer, -- if logging in via web via discord\n"
            "    google_id integer -- if logging in via web via google\n"
            ");\n"
            "create table if not exists user_lists (\n"
            "    id integer primary key,\n"
            "    user_id integer not null,\n"
            "    list_id integer not null\n"
            ");\n"
            "create table if not exists lists (\n"
            "    id integer primary key,\n"
            "    name text not null,\n"
            "    desc text\n"
            ");\n"
            "create table if not exists task_stages (\n"
            "    id integer primary key,\n"
            "    name text not null,\n"
            "    desc text,\n"
            "    list_id integer not null,\n"
            "    foreign key (list_id) references lists(id)\n"
            ");\n"
            "-- this currently enables moving tasks _between lists_ (planned of course)\n"
            "create table if not exists tasks (\n"
            "    id integer primary key,\n"
            "    name text not null,\n"
            "    desc text,\n"
            "    stage integer not null,\n"
            "    due date,\n"
            "    due_stage integer, -- more like target stage\n"
            "    foreign key (stage) references task_stages(id),\n"
            "    foreign key (due_stage) references task_stages(id)\n"
            ")";
        case ADD_USER: return "insert into users (name, local_id, discord_id, google_id) values (?1, ?2, ?3, ?4) returning id";
        case GET_USER: return "select * from users where id = ?1";
        case GET_USER_BY_LOCAL: return "select * from users where local_id = ?1";
        case GET_USER_BY_DISCORD: return "select * from users where discord_id = ?1";
        case GET_USER_BY_GOOGLE: return "select * from users where google_id = ?1";
        case GET_USERS: return "select * from users";
        case MOD_USER_NAME: return "update users set name = ?1 where id = ?2";
        case MOD_USER_LOCAL: return "update users set local_id = ?1 where id = ?2";;
        case MOD_USER_DISCORD: return "update users set discord_id = ?1 where id = ?2";
        case MOD_USER_GOOGLE: return "update users set google_id = ?1 where id = ?2";
        case DEL_USER: return "delete from users where id = ?1";
        case ADD_LIST: return "insert into lists (name, desc) values (?1, ?2)";
        case GET_LIST: return "select * from lists where id = ?1";
        case GET_LISTS: return "select * from lists";
        case GET_LISTS_BY_USER: return "select * from lists where id = (select list_id from user_lists where user_id = ?1)";
        case MOD_LIST_NAME: return "update lists set name = ?1 where id = ?2";
        case DEL_LIST: return "delete from lists where id = ?1";
        case ADD_STAGE: return "insert into task_stages (name, desc, list_id) values (?1, ?2, ?3)";
        case GET_STAGE: return "select * from task_stages where id = ?1";
        case GET_STAGES_FOR_LIST: return "select * from task_stages";
        case DEL_STAGE: return "delete from task_stages where id = ?1";
        case ADD_TASK: return "insert into tasks (name, desc, stage, due, due_stage) values (?1, ?2, ?3, ?4, ?5);";
        case GET_TASK: return "select * from tasks where id = ?1";
        case GET_TASKS: return "select * from tasks;";
        case MOD_TASK_NAME: return "update tasks set name = ?1 where id = ?2";
        case MOD_TASK_DESCRIPTION: return "update tasks set desc = ?1 where id = ?2";
        case DEL_TASK: return "delete from tasks where id = ?1";
        case _KLIST_SQL_COUNT: return "";
    }
    return "";
}
